Module: MIDIMessage::Constant::Status
Overview
Shortcuts for dealing with message status
Instance Method Summary collapse
-
#find(status_name) ⇒ String
(also: #[])
The value of the Status constant with the name status_name.
Instance Method Details
#find(status_name) ⇒ String Also known as: []
The value of the Status constant with the name status_name
163 164 165 166 |
# File 'lib/midi-message/constant.rb', line 163 def find(status_name) const = Constant.find("Status", status_name) const.value unless const.nil? end |